@@ -17,6 +17,10 @@ extern crate prettytable;
 use prettytable::Table;
 
 fn get_line_from_file(filename: &Path) -> String {
+    if !filename.exists() || !filename.is_file() {
+        println!("Cannot find file1: {:?}", filename);
+        return "".to_string();
+    }
     let file = File::open(filename).unwrap();
     let reader = BufReader::new(file);
 
@@ -62,16 +66,16 @@ fn get_line_from_cmd(line_number: i32) -> String {
     buffer.trim().to_string()
 }
 
-fn get_line(line_number: i32, filepath: Option<&Path>) -> String {
+fn get_line(line_number: i32, filepath: Option<&str>) -> String {
     match filepath {
-        Some(filepath) => get_line_from_file(filepath),
+        Some(filepath) => get_line_from_file(Path::new(filepath)),
         None => get_line_from_cmd(line_number),
     }
 }
 
 fn print_results(diffs: Vec<Difference>) {
     let mut table = Table::new();
-    table.add_row(row!["L1", "Same", "L2"]);
+    table.add_row(row!["Line 1", "Same", "Line 2"]);
     for d in diffs {
         match d {
             Same(line) => table.add_row(row!["", line, ""]),
@@ -94,15 +98,36 @@ fn main() {
     let matches = App::new("Line diff")
         .version(crate_version!())
         .author(crate_authors!())
-        .about("Compare two lines by splitting the lines into smaller chunks and comparing the chunks.")
+        .about("Compare two lines by splitting the lines into smaller chunks and comparing the chunks. \
+        There are multiple ways of specifying the two lines: \n \
+        \ta single file that contains the two lines (--file option) \n \
+        \tspecifying the two lines separately as a file path (indexed argument 1 and 2), on the command line (--line1 and --line2) or using command line input.")
+        .arg(
+            Arg::with_name("file")
+                .help("A single file containing two lines. Remaining lines will be ignored.")
+                .short("f")
+                .takes_value(true),
+        )
         .arg(
             Arg::with_name("file1")
-                .help("File containing the first line for comparison")
+                .help("Path to file containing the first line. Remaining lines will be ignored.")
                 .takes_value(true),
         )
         .arg(
             Arg::with_name("file2")
-                .help("File containing the second line for comparison")
+                .help("Path to file containing the second line. Remaining lines will be ignored.")
+                .takes_value(true),
+        )
+        .arg(
+            Arg::with_name("line1")
+                .long("line1")
+                .help("First line as string")
+                .takes_value(true),
+        )
+        .arg(
+            Arg::with_name("line2")
+                .long("line2")
+                .help("Second line as string")
                 .takes_value(true),
         )
         .arg(
@@ -119,28 +144,25 @@ fn main() {
         )
         .get_matches();
 
-    let (s1, s2) = if let Some(filepath1) = matches.value_of("file1") {
-        let path_file1 = Path::new(filepath1);
-        if !path_file1.exists() || !path_file1.is_file() {
-            println!("Cannot find file1: {}", filepath1);
+    let (s1, s2) = if let Some(filepath) = matches.value_of("file") {
+        let path_file = Path::new(filepath);
+        if !path_file.exists() || !path_file.is_file() {
+            println!("Cannot find file1: {}", filepath);
             return;
         }
-        if let Some(filepath2) = matches.value_of("file2") {
-            let path_file2 = Path::new(filepath2);
-            if !path_file2.exists() || !path_file2.is_file() {
-                println!("Cannot find file1: {}", filepath2);
-                return;
-            }
-            let s1 = get_line(1, Some(path_file1));
-            let s2 = get_line(1, Some(path_file2));
-            (s1, s2)
-        } else {
-            get_lines_from_file(path_file1)
-        }
+        get_lines_from_file(path_file)
     } else {
-        let s1 = get_line(1, None);
-        let s2 = get_line(2, None);
-        (s1, s2)
+        let l1 = if let Some(l1) = matches.value_of("line1") {
+            l1.to_owned()
+        } else {
+            get_line(1, matches.value_of("file1"))
+        };
+        let l2 = if let Some(l2) = matches.value_of("line2") {
+            l2.to_owned()
+        } else {
+            get_line(2, matches.value_of("file2"))
+        };
+        (l1, l2)
     };
 
     let sort = matches.is_present("sorted");
